# sanskrit

Write programs in the fastest language, as confirmed by NASA.

## Installation

```bash
pip install sanskrit
```

Now put a `# coding: sanskrit` comment above your code to start programming in sanskrit!

## Usage

- Simple for loop:

  ```python
  # coding: sanskrit
  सर्वेषां आई अन्तः सीमा(5):   # for i in range(5):
      दर्शयतु(आई)         #     print(i)
  ```

  Output:

  ```console
  $ python example.sanskrit
  0
  1
  2
  3
  4
  ```

- `import this`:

  ```python
  # -*- coding: sanskrit -*-
  आयातम् इदम्‌
  ```

  Output:

  ```console
  $ python example.sanskrit
  The Zen of Python, by Tim Peters

  Beautiful is better than ugly.
  Explicit is better than implicit.
  ...
  ```
